[![build](https://github.com/BoevaLab/CanSig/actions/workflows/build.yml/badge.svg?branch=main)](https://github.com/BoevaLab/CanSig/actions/workflows/build.yml)
[![docs-deploy](https://github.com/BoevaLab/CanSig/actions/workflows/docs-deploy.yml/badge.svg)](https://github.com/BoevaLab/CanSig/actions/workflows/docs-deploy.yml)
[![PyPI](https://img.shields.io/pypi/v/cansig.svg)](https://pypi.org/project/cansig)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# CanSig: Discovering de novo shared transcriptional programs in single cancer cells

A pipeline for single-cell cancer data sets analysis.

This repository accompanies [our preprint](https://doi.org/10.1101/2022.04.14.488324).

_Note: This repository is in the development stage. We hope it will soon become available._

## Resources

- For tutorials and API description, see our [documentation](https://boevalab.github.io/CanSig/).
- If you found a bug or have an idea for improvement, [submit an issue](https://boevalab.github.io/CanSig/contributing.html#submitting-an-issue).
- If you would like to contribute, see the [contribution guide](https://boevalab.github.io/CanSig/contributing.html).

## Installation

```
$ pip install cansig
```

More information can be found in the [Getting started](https://boevalab.github.io/CanSig/index.html#getting-started) section of our documentation.

## Code contributors
_To open-source the code, Git history was truncated. Hence, GitHub's statistics do not faithfully summarize the contributions. All persons listed below made major contributions to the code._

- [Josephine Yates](https://github.com/josephineyates)
- [Florian Barkmann](https://github.com/FlorianBarkmann)
- [Paweł Czyż](https://github.com/pawel-czyz)
- [Elia Saquand](https://github.com/saquand)
